==> mysql-5.6.51.tar.gz: mysql-5.6.51/storage/ndb/src/kernel/blocks/dbspj/DbspjProxy.cpp <==
/*
   Copyright (c) 2004, 2011, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "DbspjProxy.hpp"
#include "Dbspj.hpp"

DbspjProxy::DbspjProxy(Block_context& ctx) :
  LocalProxy(DBSPJ, ctx)
{
}

DbspjProxy::~DbspjProxy()
{
}

SimulatedBlock*
DbspjProxy::newWorker(Uint32 instanceNo)
{
  ndbout << "Instantiating Dbspj worker no " << instanceNo << endl;
  return new Dbspj(m_ctx, instanceNo);
}


BLOCK_FUNCTIONS(DbspjProxy)

==> mysql-8.4.8.tar.gz: mysql-8.4.8/storage/ndb/src/kernel/blocks/dbspj/DbspjProxy.cpp <==
/*
   Copyright (c) 2000, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "DbspjProxy.hpp"
#include "Dbspj.hpp"

#define JAM_FILE_ID 483

DbspjProxy::DbspjProxy(Block_context &ctx) : DbgdmProxy(DBSPJ, ctx) {}

DbspjProxy::~DbspjProxy() {}

SimulatedBlock *DbspjProxy::newWorker(Uint32 instanceNo) {
  return new Dbspj(m_ctx, instanceNo);
}

BLOCK_FUNCTIONS(DbspjProxy)
